pub struct RobustMeshBoolean;Expand description
Performs boolean operations with configurable epsilon tolerance for near-coincident geometry.
Points within epsilon of a plane boundary are snapped to the plane,
reducing numerical sensitivity in degenerate configurations.
Implementations
Sourceimpl RobustMeshBoolean
impl RobustMeshBoolean
Sourcepub fn execute(
op: BooleanOp,
mesh_a: &TriangleMesh,
mesh_b: &TriangleMesh,
epsilon: f64,
) -> Result<TriangleMesh>
pub fn execute( op: BooleanOp, mesh_a: &TriangleMesh, mesh_b: &TriangleMesh, epsilon: f64, ) -> Result<TriangleMesh>
Execute a robust boolean operation.