Module capsule

Module capsule 

Capsule shape (sphere-swept line segment along Y axis).

Structs

Capsule
A capsule defined by radius and half-height along the Y axis.
CapsuleChain
A chain of capsule segments forming a rope / chain approximation.
CapsuleFrustum
A capsule-like shape with different radii at each end (a “swept frustum”).
CurvedCapsulePath
A capsule swept along a polyline path.
DeformableCapsule
A capsule with arbitrary (deformable) endpoint positions.