pub struct LocalTransform {
pub translation: [f64; 3],
pub rot: [[f64; 3]; 3],
}Expand description
A 3-D rigid transform: translation + 3×3 rotation matrix (row-major).
The rotation rot[i] is the i-th row of the rotation matrix.
The matrix must be orthonormal; no validation is performed.
Fields
translation: [f64; 3]Translation vector.
rot: [[f64; 3]; 3]Rotation matrix stored row-major: rot[row][col].
Implementations
Sourceimpl LocalTransform
impl LocalTransform
Sourcepub fn from_translation(t: [f64; 3]) -> Self
pub fn from_translation(t: [f64; 3]) -> Self
Pure translation (no rotation).
Sourcepub fn local_to_world(&self, p: [f64; 3]) -> [f64; 3]
pub fn local_to_world(&self, p: [f64; 3]) -> [f64; 3]
Transform a point from local space to world space.
world_p = rot * local_p + translation
Sourcepub fn world_to_local(&self, p: [f64; 3]) -> [f64; 3]
pub fn world_to_local(&self, p: [f64; 3]) -> [f64; 3]
Transform a point from world space to local space.
local_p = rot^T * (world_p - translation)