pub struct NormalCone {
pub axis: [f64; 3],
pub half_angle: f64,
}Expand description
A normal cone: represents the range of normals in a region.
Defined by an axis (average normal) and a half-angle (max deviation).
Fields
axis: [f64; 3]Axis of the cone (unit vector).
half_angle: f64Half-angle of the cone in radians.
Implementations
Sourceimpl NormalCone
impl NormalCone
Sourcepub fn from_normal(n: [f64; 3]) -> Self
pub fn from_normal(n: [f64; 3]) -> Self
Create a normal cone from a single normal vector.
Sourcepub fn merge(&self, other: &NormalCone) -> NormalCone
pub fn merge(&self, other: &NormalCone) -> NormalCone
Merge two normal cones into a bounding cone.
Sourcepub fn contains(&self, n: [f64; 3], tol: f64) -> bool
pub fn contains(&self, n: [f64; 3], tol: f64) -> bool
Check whether a new normal falls within this cone (with tolerance tol).
Sourcepub fn half_angle_deg(&self) -> f64
pub fn half_angle_deg(&self) -> f64
Convert half-angle to degrees.