pub struct VertexVectorField {
pub num_vertices: usize,
pub vectors: Vec<[f64; 3]>,
}Expand description
A discrete vertex vector field, storing one tangent vector per vertex.
Fields
num_vertices: usizeNumber of vertices.
vectors: Vec<[f64; 3]>Per-vertex tangent vectors.
Implementations
Sourceimpl VertexVectorField
impl VertexVectorField
Sourcepub fn divergence(&self, mesh: &DiscreteMesh) -> Vec<f64>
pub fn divergence(&self, mesh: &DiscreteMesh) -> Vec<f64>
Compute the divergence of the vertex vector field as a scalar on vertices.
Sourcepub fn curl_on_faces(&self, mesh: &DiscreteMesh) -> Vec<f64>
pub fn curl_on_faces(&self, mesh: &DiscreteMesh) -> Vec<f64>
Compute the curl (discrete 2-form = scalar on faces) of the vertex vector field.