SdfRoundedCylinder

Struct SdfRoundedCylinder 

pub struct SdfRoundedCylinder {
    pub radius: f64,
    pub half_height: f64,
    pub rounding: f64,
}
SDF for a rounded cylinder aligned with the Y axis.

Cylinder of radius and half_height, with hemisphere caps of the same radius (i.e. a capsule-like shape but with flat lateral surface).

Fields

radius: f64

Cylinder radius [m].

half_height: f64

Half-height of the cylindrical body [m].

rounding: f64

Corner rounding radius [m].

Implementations

Source

impl SdfRoundedCylinder

pub fn new(radius: f64, half_height: f64, rounding: f64) -> Self

Create a rounded cylinder SDF.