pub struct FeatureEdge {
pub v0: usize,
pub v1: usize,
pub dihedral_angle: f64,
}Expand description
A feature edge defined by its two endpoint vertex indices and the dihedral angle between the two adjacent faces.
Fields
v0: usizeFirst vertex index.
v1: usizeSecond vertex index.
dihedral_angle: f64Dihedral angle between adjacent faces in radians.