offset_curve_3d

Function offset_curve_3d 

pub fn offset_curve_3d(
    pts: &[[f64; 3]],
    normal: [f64; 3],
    d: f64,
) -> Vec<[f64; 3]>
Offset a 3D polyline by d along a fixed normal direction.

Returns a new set of points displaced by d * normal.