Module quickhull

Module quickhull 

3D Convex Hull via QuickHull algorithm.

Provides convex hull construction, vertex/face/edge enumeration, volume and surface area computation, point-in-hull test, hull merging, and support queries.

Structs

ConflictGraph
A conflict graph recording which faces can “see” which points outside the hull.
ConvexHull3DVec
3D Convex Hull computed via QuickHull algorithm (nalgebra Vec3 variant).
IncrementalConvexHull
Incremental convex hull that can accept new points one at a time.

Functions

build_with_indices
Compute convex hull and return both hull and the indices (into original point cloud) of vertices on the hull.
hull_inertia_tensor
Compute the inertia tensor of a convex hull treated as a uniform solid.
is_point_set_convex
Check if a point set is convex (i.e., all points lie on the hull).
merge_hulls
Merge two convex hulls into one by computing the hull of the union of vertices.