pub struct IncrementalConvexHull {
pub all_points: Vec<Vec3>,
pub faces: Vec<[usize; 3]>,
pub hull_verts: Vec<usize>,
}Expand description
Incremental convex hull that can accept new points one at a time.
Internally maintains the same triangulated hull structure as ConvexHull3DVec.
Fields
all_points: Vec<Vec3>All points ever inserted.
faces: Vec<[usize; 3]>Current hull faces.
hull_verts: Vec<usize>Current hull vertex indices (into all_points).
Implementations
Sourceimpl IncrementalConvexHull
impl IncrementalConvexHull
Sourcepub fn build(points: &[Vec3]) -> Self
pub fn build(points: &[Vec3]) -> Self
Build an incremental hull from a slice of initial points.
Sourcepub fn n_vertices(&self) -> usize
pub fn n_vertices(&self) -> usize
Number of vertices on the current hull.
Sourcepub fn euler_characteristic(&self) -> i64
pub fn euler_characteristic(&self) -> i64
Euler characteristic V - E + F = 2.