pub struct CubicSpline {
pub x: Vec<f64>,
pub a: Vec<f64>,
pub b: Vec<f64>,
pub c: Vec<f64>,
pub d: Vec<f64>,
}Expand description
Result of cubic spline interpolation: piece-wise cubic coefficients.
Each segment [x[i\], x[i+1]] has coefficients (a, b, c, d) such that
S(x) = a + b*(x - x[i]) + c*(x - x[i])^2 + d*(x - x[i])^3.
Fields
x: Vec<f64>x-knots (must be strictly increasing).
a: Vec<f64>Coefficients a (= y values at left knot).
b: Vec<f64>Coefficients b.
c: Vec<f64>Coefficients c.
d: Vec<f64>Coefficients d.
Implementations
Sourceimpl CubicSpline
impl CubicSpline
Sourcepub fn natural(x: Vec<f64>, y: Vec<f64>) -> Self
pub fn natural(x: Vec<f64>, y: Vec<f64>) -> Self
Build a natural cubic spline through the given (x, y) data.
Natural boundary: second derivative = 0 at both endpoints.
Sourcepub fn clamped(x: Vec<f64>, y: Vec<f64>, d0: f64, dn: f64) -> Self
pub fn clamped(x: Vec<f64>, y: Vec<f64>, d0: f64, dn: f64) -> Self
Build a clamped cubic spline with given endpoint slopes d0 and dn.
Sourcepub fn eval_derivative(&self, t: f64) -> f64
pub fn eval_derivative(&self, t: f64) -> f64
Evaluate the first derivative at t.
Sourcepub fn eval_second_derivative(&self, t: f64) -> f64
pub fn eval_second_derivative(&self, t: f64) -> f64
Evaluate the second derivative at t.