pub enum AdaptiveCriterion {
MaxEdgeLength(f64),
AspectRatio(f64),
NearVertices,
}Expand description
Criterion for adaptive subdivision.
Variants
MaxEdgeLength(f64)
Subdivide faces where any edge is longer than max_edge_length.
AspectRatio(f64)
Subdivide faces where the triangle aspect ratio exceeds the threshold.
NearVertices
Subdivide faces that contain any of the listed vertex indices.