SweptBox

Struct SweptBox 

pub struct SweptBox {
    pub transform_start: [[f64; 4]; 4],
    pub transform_end: [[f64; 4]; 4],
    pub half_extents: [f64; 3],
}
A box swept along a path defined by a start and end transform.

The conservative AABB encloses the box at both the start and end poses.

Fields

transform_start: [[f64; 4]; 4]

Homogeneous transform (row-major 4x4) at the start of the sweep.

transform_end: [[f64; 4]; 4]

Homogeneous transform (row-major 4x4) at the end of the sweep.

half_extents: [f64; 3]

Half-extents of the box along its local axes.

Implementations

Source

impl SweptBox

pub fn new( transform_start: [[f64; 4]; 4], transform_end: [[f64; 4]; 4], half_extents: [f64; 3], ) -> Self

Create a new SweptBox.

pub fn aabb(&self) -> ([f64; 3], [f64; 3])

Conservative AABB enclosing the box at both the start and end poses.

All 8 corners of the box are transformed into world space at each endpoint and the result is the union of the two world-space AABBs.

pub fn aabb_sampled(&self, n_samples: usize) -> ([f64; 3], [f64; 3])

Conservative AABB including n_samples intermediate poses.

pub fn box_volume(&self) -> f64

Volume of the box (static).

pub fn start_translation(&self) -> [f64; 3]

Translation at the start pose.

pub fn end_translation(&self) -> [f64; 3]

Translation at the end pose.

pub fn displacement(&self) -> [f64; 3]

Displacement vector from start to end translation.