pub struct SweptCapsule {
pub position_start: [f64; 3],
pub position_end: [f64; 3],
pub radius: f64,
pub half_height: f64,
}Expand description
A capsule swept along a straight line defined by start and end positions.
The capsule itself is axis-aligned along the Y axis with given radius
and half_height. The swept volume is the Minkowski sum of the capsule
with the line segment.
Fields
position_start: [f64; 3]World-space position of the capsule center at start.
position_end: [f64; 3]World-space position of the capsule center at end.
radius: f64Capsule radius.
half_height: f64Capsule half-height (distance from centre to each hemisphere centre).
Implementations
Sourceimpl SweptCapsule
impl SweptCapsule
Sourcepub fn new(
position_start: [f64; 3],
position_end: [f64; 3],
radius: f64,
half_height: f64,
) -> Self
pub fn new( position_start: [f64; 3], position_end: [f64; 3], radius: f64, half_height: f64, ) -> Self
Create a new SweptCapsule.
Sourcepub fn position_at(&self, t: f64) -> [f64; 3]
pub fn position_at(&self, t: f64) -> [f64; 3]
Position at parametric time t.
Sourcepub fn capsule_volume(&self) -> f64
pub fn capsule_volume(&self) -> f64
Volume of the capsule (static, not swept).