pub enum RidgeValley {
Ridge,
Valley,
Slope,
}Expand description
Classify each cell as ridge, valley, or neither.
Variants
Ridge
Local elevation maximum in at least one principal direction.
Valley
Local elevation minimum in at least one principal direction.
Slope
Neither ridge nor valley.