pub fn classify_feature_vertices(
mesh: &SimpleMesh,
threshold_rad: f64,
) -> Vec<bool>Expand description
Classify every vertex as smooth or feature based on the maximum dihedral angle between its adjacent triangle faces.
A vertex is marked as a feature vertex when any pair of its adjacent faces
has a dihedral angle exceeding threshold_rad.