pub struct FaceVectorField {
pub num_faces: usize,
pub vectors: Vec<[f64; 3]>,
}Expand description
A discrete vector field on a mesh, storing one tangent vector per face.
Vectors are stored in 3D ambient space but should lie in the tangent plane of the respective face.
Fields
num_faces: usizeNumber of faces in the underlying mesh.
vectors: Vec<[f64; 3]>Per-face tangent vectors.
Implementations
Sourceimpl FaceVectorField
impl FaceVectorField
Sourcepub fn from_vec(vectors: Vec<[f64; 3]>) -> Self
pub fn from_vec(vectors: Vec<[f64; 3]>) -> Self
Construct from a given list of per-face vectors.
Sourcepub fn project_to_tangent(&mut self, mesh: &DiscreteMesh)
pub fn project_to_tangent(&mut self, mesh: &DiscreteMesh)
Project each face vector into the tangent plane of the face.