pub struct TubeGeometry {
pub vertices: Vec<[f64; 3]>,
pub triangles: Vec<[usize; 3]>,
}Expand description
A tube mesh built by extruding a circular cross-section along a spine curve.
Uses the Frenet frame at each spine sample to orient the cross-section circles, then connects them into a triangle strip.
Fields
vertices: Vec<[f64; 3]>Vertex positions.
triangles: Vec<[usize; 3]>Triangle indices (each triple is one triangle, CCW from outside).
Implementations
Sourceimpl TubeGeometry
impl TubeGeometry
Sourcepub fn from_bezier(
curve: &BezierCurve,
radius: f64,
n_spine: usize,
n_radial: usize,
) -> Self
pub fn from_bezier( curve: &BezierCurve, radius: f64, n_spine: usize, n_radial: usize, ) -> Self
Build a tube along a BezierCurve.
Parameters
curve: The spine curve.radius: Radius of the circular cross-section.n_spine: Number of spine samples (at least 2).n_radial: Number of vertices around each ring (at least 3).