3D Convex Hull via QuickHull algorithm.
Provides convex hull construction, vertex/face/edge enumeration, volume and surface area computation, point-in-hull test, hull merging, and support queries.
Structs
- Conflict
Graph - A conflict graph recording which faces can “see” which points outside the hull.
- Convex
Hull3D Vec - 3D Convex Hull computed via QuickHull algorithm (nalgebra Vec3 variant).
- Incremental
Convex Hull - Incremental convex hull that can accept new points one at a time.
Functions
- build_
with_ indices - Compute convex hull and return both hull and the indices (into original point cloud) of vertices on the hull.
- hull_
inertia_ tensor - Compute the inertia tensor of a convex hull treated as a uniform solid.
- is_
point_ set_ convex - Check if a point set is convex (i.e., all points lie on the hull).
- merge_
hulls - Merge two convex hulls into one by computing the hull of the union of vertices.