pub struct SweptAabb {
pub start_min: [f64; 3],
pub start_max: [f64; 3],
pub end_min: [f64; 3],
pub end_max: [f64; 3],
}Expand description
A shape defined by its start and end AABB — the swept union.
This represents the conservative volume swept by an AABB moving linearly
from start to end (i.e., the union of the two AABBs and everything in
between along each axis).
Fields
start_min: [f64; 3]AABB at the start: (min, max).
start_max: [f64; 3]AABB at the start: max corner.
end_min: [f64; 3]AABB at the end: min corner.
end_max: [f64; 3]AABB at the end: max corner.
Implementations
Sourceimpl SweptAabb
impl SweptAabb
Sourcepub fn new(
start_min: [f64; 3],
start_max: [f64; 3],
end_min: [f64; 3],
end_max: [f64; 3],
) -> Self
pub fn new( start_min: [f64; 3], start_max: [f64; 3], end_min: [f64; 3], end_max: [f64; 3], ) -> Self
Create a new SweptAabb.
Sourcepub fn contains_point(&self, p: [f64; 3]) -> bool
pub fn contains_point(&self, p: [f64; 3]) -> bool
Test whether a static point is inside the swept volume AABB.
Sourcepub fn displacement(&self) -> [f64; 3]
pub fn displacement(&self) -> [f64; 3]
Displacement of the AABB centre from start to end.