AlphaComplex

Struct AlphaComplex 

pub struct AlphaComplex {
    pub alpha: f64,
    pub points: Vec<[f64; 3]>,
    pub edges: Vec<[usize; 2]>,
    pub triangles: Vec<[usize; 3]>,
}
Alpha complex / alpha shapes for point clouds.

An alpha complex is a subset of the Delaunay triangulation based on a circumradius threshold α.

Fields

alpha: f64

Alpha parameter (circumradius threshold)

points: Vec<[f64; 3]>

Points in the cloud

edges: Vec<[usize; 2]>

Edges included at this alpha value

triangles: Vec<[usize; 3]>

Triangles included at this alpha value

Implementations

Source

impl AlphaComplex

pub fn new(points: Vec<[f64; 3]>, alpha: f64) -> Self

Creates an alpha complex from a point cloud.

Arguments
  • points - Point cloud
  • alpha - Circumradius threshold (larger = more simplices)
pub fn n_components(&self) -> usize

Returns the number of connected components at this alpha.

pub fn to_simplicial_complex(&self) -> SimplicialComplex

Returns the simplicial complex at this alpha level.